summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/3812intf.cpp
diff options
context:
space:
mode:
author Aaron Giles <aaron@aarongiles.com>2020-09-21 20:45:38 -0700
committer Aaron Giles <aaron@aarongiles.com>2020-09-21 20:45:38 -0700
commitf051f97e6c16374bf2612b98be4c67d64695cbd7 (patch)
tree25fb85c2f134676fc4de852097140ca088ed1775 /src/devices/sound/3812intf.cpp
parentecd3333757e171d5d98bc323dba1f7c403386e11 (diff)
ym2203/ym2608/ym2610/ym2612/ymf262/ym3526/ym3812/y8950/ym2413/ymf271/ymf278b/ymz280b/ymz770/zsg2: update to new stream callbacks
Diffstat (limited to 'src/devices/sound/3812intf.cpp')
-rw-r--r--src/devices/sound/3812intf.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/devices/sound/3812intf.cpp b/src/devices/sound/3812intf.cpp
index b9287f21d9e..c74c75e27b0 100644
--- a/src/devices/sound/3812intf.cpp
+++ b/src/devices/sound/3812intf.cpp
@@ -62,12 +62,12 @@ void ym3812_device::timer_handler(int c, const attotime &period)
//-------------------------------------------------
// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------
-void ym3812_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
+void ym3812_device::sound_stream_update(sound_stream &stream, std::vector<read_stream_view> const &inputs, std::vector<write_stream_view> &outputs)
{
- ym3812_update_one(m_chip, outputs[0], samples);
+ ym3812_update_one(m_chip, outputs[0]);
}
//-------------------------------------------------
@@ -110,7 +110,7 @@ void ym3812_device::calculate_rates()
if (m_stream != nullptr)
m_stream->set_sample_rate(rate);
else
- m_stream = stream_alloc_legacy(0, 1, rate);
+ m_stream = stream_alloc(0, 1, rate);
}
//-------------------------------------------------
@@ -62,12 +62,12 @@ void ym3812_device::timer_handler(int c, const attotime &period)
//-------------------------------------------------
-// sound_stream_update_legacy - handle a stream update
+// sound_stream_update - handle a stream update
//-------------------------------------------------